package query

import (
	"net/http"

	"tyc-server/app/user/cmd/api/internal/logic/query"
	"tyc-server/app/user/cmd/api/internal/svc"
	"tyc-server/app/user/cmd/api/internal/types"
	"tyc-server/common/result"
	"tyc-server/pkg/lzkit/validator"

	"github.com/zeromicro/go-zero/rest/httpx"
)

func QueryListHandler(svcCtx *svc.ServiceContext) http.HandlerFunc {
	return func(w http.ResponseWriter, r *http.Request) {
		var req types.QueryListReq
		if err := httpx.Parse(r, &req); err != nil {
			result.ParamErrorResult(r, w, err)
			return
		}
		if err := validator.Validate(req); err != nil {
			result.ParamValidateErrorResult(r, w, err)
			return
		}
		l := query.NewQueryListLogic(r.Context(), svcCtx)
		resp, err := l.QueryList(&req)
		result.HttpResult(r, w, resp, err)
	}
}
